@@ -254,7 +254,8 @@ class Insight_Definition:
 
         position = (len(self.components))
         body = {"type": "table", "position": position}
-
+        print("BODY")
+        print(body)
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -453,6 +454,25 @@ class Insight_Definition:
         return data_id
 
 
+    def add_query_composer(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
+        qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)
+        position = (len(self.components))
+        qc_post_url = self.smart_insight_url + "/definitions/" + self.definition_id + "/query_composers"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        body = {"type": "query_composer", "position": position, "qc": qc_id}
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=qc_post_url, json=body, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+        self.components = r["components"]
+
+
     def create_qc(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
         """
         Pivot columns MUST be contained in field list
@@ -473,7 +493,7 @@ class Insight_Definition:
             retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
             s.mount('https://', HTTPAdapter(max_retries=retries))
 
-            url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self._slug + '/datasetslug/' + dataset_slug
+            url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self.agent_slug + '/datasetslug/' + dataset_slug
 
             headers = {"Authorization": "Bearer" + " " + self._token}
             response = s.get(url=url, headers=headers)
@@ -509,21 +529,29 @@ class Insight_Definition:
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.post(url=url, json=body, headers=headers)
         response.raise_for_status()
-
+        print(response.json())
         qc_id = response.json()["id"]
 
         return qc_id
 
+    def get_component(self, component_id):
+        for component in self.components:
+            if (component["id"] == component_id):
+                return component
+
+
     def add_query_composer_to_data_component(self, data_id, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50, offset=0, pivot=[]):
 
         qc_id = self.create_qc(dataset_slug, fields, filters, sorted_by, dataset_id, limit, offset, pivot)
-
+        name = self.get_component(data_id)["settings"]["name"]
+        variable_name = self.get_component(data_id)["settings"]["variableName"]
         body = {
+            "name": name,
+            "variableName": variable_name,
             "qcId": qc_id
         }
-
-        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id+"/data"
-        #logging.info("URL: {}".format(url))
+        print(body)
+        url = self._base_url_askdata+"/smartinsight/definitions/"+self.definition_id+"/data_queries/"+data_id
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -533,7 +561,7 @@ class Insight_Definition:
             "Content-Type": "application/json",
             "Authorization": "Bearer" + " " + self._token
         }
-        r = s.put(url=url, data=body, headers=headers)
+        r = s.put(url=url, json=body, headers=headers)
         r.raise_for_status()
         self.components = r.json()["components"]
 
