@@ -354,46 +354,17 @@ class Query:
                         and where_condition.field.sourceDataType.lower() not in consistent_vec:
                     # if internal and original data types are not consistent each other use this pattern
                     # aggregation column (original data type, to internal data type ) AS Alias
-                    if where_condition.field.aggregation is not None and isinstance(
-                            where_condition.field.aggregation, str):
-                        formatted_cond = where_condition.field.aggregation + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                    elif where_condition.field.aggregation is not None and isinstance(
-                            where_condition.field.aggregation, SQLFunction):
-                        formatted_cond = where_condition.field.aggregation.name + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                    else:
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
+                    formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
                 elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
                     # if internal and original data types are not consistent each other use this pattern
                     # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
                     if where_condition.field.sourceFormat is not None:
-                        if where_condition.field.aggregation is not None and isinstance(
-                                where_condition.field.aggregation, str):
-                            formatted_cond = where_condition.field.aggregation + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
-                        elif where_condition.field.aggregation is not None and isinstance(
-                                where_condition.field.aggregation, SQLFunction):
-                            formatted_cond = where_condition.field.aggregation.name + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
-                        else:
-                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
                     else:
-                        if where_condition.field.aggregation is not None and isinstance(
-                                where_condition.field.aggregation, str):
-                            formatted_cond = where_condition.field.aggregation + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
-                        elif where_condition.field.aggregation is not None and isinstance(
-                                where_condition.field.aggregation, SQLFunction):
-                            formatted_cond = where_condition.field.aggregation.name + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
-                        else:
-                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
+                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
                 else:
                     # else
-                    if where_condition.field.aggregation is not None and isinstance(
-                            where_condition.field.aggregation, str):
-                        formatted_cond = where_condition.field.aggregation + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
-                    elif where_condition.field.aggregation is not None and isinstance(
-                            where_condition.field.aggregation,
-                            SQLFunction):
-                        formatted_cond = where_condition.field.aggregation.name + " " + where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
-                    else:
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+                    formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
 
                 conditions.append(formatted_cond)
             elif isinstance(where_condition, CompositeCondition):
